import pickle
import datetime
import os

def save_model(model, custom_path='D:/suan/Code_suan/', prefix='my_model_'):
    """
    将模型保存为一个文件，文件名包括时间戳，防止覆盖。
    
    :param model: 训练好的模型（例如 RandomForestRegressor)
    :param custom_path: 保存模型的路径，默认是 'D:/suan/Code_suan/'
    :param prefix: 文件名前缀，默认是 'my_model_'
    """
    # 确保路径存在
    os.makedirs(custom_path, exist_ok=True)
    
    # 获取当前时间戳（格式：月日时分）
    timestamp = datetime.datetime.now().strftime('%m%d_%H%M')

    # 拼接完整的文件名
    file_name = os.path.join(custom_path, f'{prefix}{timestamp}.pkl')

    # 保存模型
    with open(file_name, 'wb') as f:
        pickle.dump(model, f)

    print(f"模型已保存为: {file_name}")
